Welcome to modlAMP’s documentation! — modlAMP v4.1.2 documentation

# Welcome to modlAMP’s documentation!

modlAMP

Authors: Alex Müller, Gisela Gabernet

Copyright: (c) 2016 - 2019 ETH Zurich, Switzerland; Alex Müller, Gisela Gabernet, Gisbert Schneider (modlab).

This is a Python package (for Python 3 since version 4.0.0) that was designed for working with peptides, proteins or any sequence of natural amino acids. It incorporates several modules, like sequence generation (module `sequences`), sequence library analysis (module `analysis`) or descriptor calculation (module `descriptors`). For basic instructions on how to use the package, check the README or the example script. The project’s GitHub page can be found here: http://github.com/alexarnimueller/modlamp

The package has the following contents:

- 1. README
  - 1.1. Installation
  - 1.2. Usage
    - 1.2.1. Importing modules
    - 1.2.2. Generating Sequences
    - 1.2.3. Calculating Descriptor Values
    - 1.2.4. Plotting Features
    - 1.2.5. Database Connection
    - 1.2.6. Loading Prepared Datasets
    - 1.2.7. Analysing Wetlab Circular Dichroism Data
    - 1.2.8. Analysis of Different Sequence Libraries
    - 1.2.9. Documentation
    - 1.2.10. Citing modlAMP
- 2. Package Documentation
  - 2.1. modlamp.descriptors
  - 2.2. modlamp.sequences
  - 2.3. modlamp.database
  - 2.4. modlamp.datasets
  - 2.5. modlamp.plot
  - 2.6. modlamp.ml
  - 2.7. modlamp.wetlab
  - 2.8. modlamp.analysis
  - 2.9. modlamp.core
- 3. Example scripts
  - 3.1. A modlamp example script for peptide classification with a Random Forest classifier.
  - 3.2. An alternative example for single peptide classification with a RF classifier.
  - 3.3. Loading sequences from a `FASTA` file
  - 3.4. Combining different descriptors & saving to `csv`
- 4. LICENSE
- 5. TODOs

If you use modlAMP in a scientific publication, we would appreciate citations to the following paper:

Müller A. T. et al. (2017) modlAMP: Python for anitmicrobial peptides, Bioinformatics 33, (17), 2753-2755, DOI:10.1093/bioinformatics/btx285.

# Indices and tables

- Index

- Module Index

- Search Page